@@ -1,3 +1,4 @@
+from http.client import HTTPConnection, HTTPSConnection
 from random import shuffle as _shuffle
 from socket import (
     SOL_SOCKET,
@@ -41,27 +42,28 @@ def check_addr(addr: tuple, timeout=1, iface: str = None):
             break
 
 
-def check_path(host,
-               port=80,
-               path='/',
-               headers=HEADERS,
-               ssl=False,
-               verify=False,
-               timeout=2):
+def http_connection(host: str, port=80, ssl=False, verify=False, timeout=2):
     if ssl:
-        from http.client import HTTPSConnection
         if verify:
             c = HTTPSConnection(host, port, timeout=timeout)
         else:
             c = HTTPSConnection(host, port, context=_cuc(), timeout=timeout)
     else:
-        from http.client import HTTPConnection
         c = HTTPConnection(host, port, timeout=timeout)
+    return c
+
+
+def http_request(connection: HTTPConnection, path, headers: dict = HEADERS):
+    connection.request('GET', path, headers=headers)
+    response = connection.getresponse()
+    return response.status, response.read()
+
+
+def check_path(host, port=80, path='/', headers=HEADERS, ssl=False, timeout=2):
+    c = http_connection(host, port, ssl, False, timeout)
 
     try:
-        c.request('GET', path, headers=headers)
-        r = c.getresponse()
-        return r.status, r.read()
+        return http_request(c, path, headers)
     except KeyboardInterrupt:
         raise
     except:
